API documentation
=================

This is the definite source of information for developers, besides having a look at the actual source code. Each class and public method should be fully documented.

.. toctree::
   :maxdepth: 1
   :hidden:

   aspecd.analysis
   aspecd.annotation
   aspecd.dataset
   aspecd.exceptions
   aspecd.history
   aspecd.infofile
   aspecd.io
   aspecd.metadata
   aspecd.model
   aspecd.plotting
   aspecd.processing
   aspecd.report
   aspecd.system
   aspecd.table
   aspecd.tasks
   aspecd.utils


Module contents
---------------

.. automodule:: aspecd
    :members:
    :undoc-members:
    :show-inheritance:


Index
-----

* :ref:`genindex`
